@@ -1,6 +1,6 @@
 from extras.plugins import PluginConfig
 
-__version__ = "0.0.0.0.44"
+__version__ = "0.0.0.0.59"
 
 
 class OCPProjectConfig(PluginConfig):
@@ -11,7 +11,7 @@ class OCPProjectConfig(PluginConfig):
     version = __version__
     author = "Tim Rhomberg"
     author_email = "timrhomberg@hotmail.com"
-    required_settings = []
+    required_settings = ["gitlab_project_url", "values_path", "default_access_token"]
     base_url = "ocp-project-plugin"
 
 
