@@ -17,8 +17,8 @@ class AppEnvironmentFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = AppEnvironment
-        fields = ["app_env", "mtls", "repo", "branch", "path", "egress_ip", "helm", "monitoring", "postgres_monitoring",
-                  "kustomize", "ocp_project"]
+        fields = ["app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring", "postgres_monitoring",
+                  "ocp_project"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -31,10 +31,9 @@ class AppEnvironmentFilter(NetBoxModelFilterSet):
             | Q(branch__icontains=value)
             | Q(path__icontains=value)
             | Q(egress_ip__icontains=value)
-            | Q(helm__icontains=value)
+            | Q(deployment_kind__icontains=value)
             | Q(monitoring__icontains=value)
             | Q(postgres_monitoring__icontains=value)
-            | Q(kustomize__icontains=value)
             | Q(ocp_project__icontains=value)
         )
         return queryset.filter(qs_filter)
