@@ -4,6 +4,7 @@ from django.urls import reverse
 from netbox.models import NetBoxModel
 from ocp_project_plugin.choices import AppEnvironmentClusterEnvChoices, AppEnvironmentDeploymentKindChoices
 from ocp_project_plugin.models import OCPProject
+from ocp_project_plugin.utils.gitlab import clone_repo
 
 
 class AppEnvironment(NetBoxModel):
@@ -111,3 +112,6 @@ class AppEnvironment(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/AppEnvironment/'
 
+    def save(self, *args, **kwargs):
+        clone_repo()
+        super(AppEnvironment, self).save(*args, **kwargs)
